"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AdditionalAssembly = void 0;
const Exceptions_1 = require("../../Exceptions");
const StringUtil_1 = require("../../Utility/StringUtil");
class AdditionalAssembly {
    constructor() {
    }
    static onlyUsings(usings) {
        if (!usings || usings.length === 0) {
            (0, Exceptions_1.throwError)("InvalidArgumentException", "Using cannot be null or empty");
        }
        const additionalAssembly = new AdditionalAssembly();
        additionalAssembly.usings = usings;
        return additionalAssembly;
    }
    static fromRuntime(assemblyName, usings = null) {
        if (StringUtil_1.StringUtil.isNullOrWhitespace(assemblyName)) {
            (0, Exceptions_1.throwError)("InvalidArgumentException", "AssemblyName cannot be null or whitespace.");
        }
        const additionalAssembly = new AdditionalAssembly();
        additionalAssembly.assemblyName = assemblyName;
        additionalAssembly.usings = usings;
        return additionalAssembly;
    }
    static fromPath(assemblyPath, usings = null) {
        if (StringUtil_1.StringUtil.isNullOrWhitespace(assemblyPath)) {
            (0, Exceptions_1.throwError)("InvalidArgumentException", "AssemblyPath cannot be null or whitespace.");
        }
        const additionalAssembly = new AdditionalAssembly();
        additionalAssembly.assemblyPath = assemblyPath;
        additionalAssembly.usings = usings;
        return additionalAssembly;
    }
    static fromNuGet(packageName, packageVersion, packageSourceUrl = null, usings = null) {
        if (StringUtil_1.StringUtil.isNullOrWhitespace(packageName)) {
            (0, Exceptions_1.throwError)("InvalidArgumentException", "PackageName cannot be null or whitespace.");
        }
        if (StringUtil_1.StringUtil.isNullOrWhitespace(packageVersion)) {
            (0, Exceptions_1.throwError)("InvalidArgumentException", "PackageVersion cannot be null or whitespace.");
        }
        const additionalAssembly = new AdditionalAssembly();
        additionalAssembly.packageName = packageName;
        additionalAssembly.packageVersion = packageVersion;
        additionalAssembly.packageSourceUrl = packageSourceUrl;
        additionalAssembly.usings = usings;
        return additionalAssembly;
    }
}
exports.AdditionalAssembly = AdditionalAssembly;
//# sourceMappingURL=AdditionalAssembly.js.map