"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AbstractMultiMapCountersIndexCreationTask = void 0;
const AbstractGenericCountersIndexCreationTask_1 = require("./AbstractGenericCountersIndexCreationTask");
const Exceptions_1 = require("../../../Exceptions");
const CountersIndexDefinitionBuilder_1 = require("./CountersIndexDefinitionBuilder");
const DocumentConventions_1 = require("../../Conventions/DocumentConventions");
class AbstractMultiMapCountersIndexCreationTask extends AbstractGenericCountersIndexCreationTask_1.AbstractGenericCountersIndexCreationTask {
    constructor() {
        super(...arguments);
        this.maps = [];
    }
    _addMap(map) {
        if (!map) {
            (0, Exceptions_1.throwError)("InvalidArgumentException", "Map cannot be null");
        }
        this.maps.push(map);
    }
    createIndexDefinition() {
        if (!this.conventions) {
            this.conventions = new DocumentConventions_1.DocumentConventions();
        }
        const indexDefinitionBuilder = new CountersIndexDefinitionBuilder_1.CountersIndexDefinitionBuilder(this.getIndexName());
        indexDefinitionBuilder.indexesStrings = this._indexesStrings;
        indexDefinitionBuilder.analyzersStrings = this._analyzersStrings;
        indexDefinitionBuilder.reduce = this._reduce;
        indexDefinitionBuilder.storesStrings = this._storesStrings;
        indexDefinitionBuilder.suggestionsOptions = this._indexSuggestions;
        indexDefinitionBuilder.termVectorsStrings = this._termVectorsStrings;
        indexDefinitionBuilder.spatialIndexesStrings = this._spatialOptionsStrings;
        indexDefinitionBuilder.outputReduceToCollection = this._outputReduceToCollection;
        indexDefinitionBuilder.patternForOutputReduceToCollectionReferences = this._patternForOutputReduceToCollectionReferences;
        indexDefinitionBuilder.patternReferencesCollectionName = this._patternReferencesCollectionName;
        indexDefinitionBuilder.additionalSources = this.additionalSources;
        indexDefinitionBuilder.additionalAssemblies = this.additionalAssemblies;
        indexDefinitionBuilder.configuration = this.configuration;
        indexDefinitionBuilder.lockMode = this.lockMode;
        indexDefinitionBuilder.priority = this.priority;
        indexDefinitionBuilder.state = this.state;
        indexDefinitionBuilder.deploymentMode = this.deploymentMode;
        const indexDefinition = indexDefinitionBuilder.toIndexDefinition(this.conventions, false);
        indexDefinition.maps = new Set(this.maps);
        return indexDefinition;
    }
}
exports.AbstractMultiMapCountersIndexCreationTask = AbstractMultiMapCountersIndexCreationTask;
//# sourceMappingURL=AbstractMultiMapCountersIndexCreationTask.js.map