"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UnregisterReplicationHubAccessOperation = void 0;
const StringUtil_1 = require("../../../Utility/StringUtil");
const Exceptions_1 = require("../../../Exceptions");
const RavenCommand_1 = require("../../../Http/RavenCommand");
const RaftIdGenerator_1 = require("../../../Utility/RaftIdGenerator");
class UnregisterReplicationHubAccessOperation {
    constructor(hubName, thumbprint) {
        if (StringUtil_1.StringUtil.isNullOrEmpty(hubName)) {
            (0, Exceptions_1.throwError)("InvalidArgumentException", "HubName cannot be null or whitespace");
        }
        if (StringUtil_1.StringUtil.isNullOrEmpty(thumbprint)) {
            (0, Exceptions_1.throwError)("InvalidArgumentException", "Thumbprint cannot be null or whitespace.");
        }
        this._hubName = hubName;
        this._thumbprint = thumbprint;
    }
    get resultType() {
        return "CommandResult";
    }
    getCommand(conventions) {
        return new UnregisterReplicationHubAccessCommand(this._hubName, this._thumbprint);
    }
}
exports.UnregisterReplicationHubAccessOperation = UnregisterReplicationHubAccessOperation;
class UnregisterReplicationHubAccessCommand extends RavenCommand_1.RavenCommand {
    constructor(hubName, thumbprint) {
        super();
        this._hubName = hubName;
        this._thumbprint = thumbprint;
        this._responseType = "Empty";
    }
    createRequest(node) {
        const uri = node.url + "/databases/" + node.database
            + "/admin/tasks/pull-replication/hub/access?name=" + this._urlEncode(this._hubName)
            + "&thumbprint=" + this._urlEncode(this._thumbprint);
        return {
            uri,
            method: "DELETE"
        };
    }
    get isReadRequest() {
        return false;
    }
    getRaftUniqueRequestId() {
        return RaftIdGenerator_1.RaftIdGenerator.newId();
    }
}
//# sourceMappingURL=UnregisterReplicationHubAccessOperation.js.map