"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LazyQueryOperation = void 0;
const GetRequest_1 = require("../../../Commands/MultiGet/GetRequest");
const IndexQuery_1 = require("../../../Queries/IndexQuery");
const QueryCommand_1 = require("../../../Commands/QueryCommand");
const StreamUtil_1 = require("../../../../Utility/StreamUtil");
class LazyQueryOperation {
    constructor(session, queryOperation, parent, clazz) {
        this._clazz = clazz;
        this._session = session;
        this._queryOperation = queryOperation;
        this._parent = parent;
    }
    createRequest() {
        const request = new GetRequest_1.GetRequest();
        request.canCacheAggressively = !this._queryOperation.indexQuery.disableCaching && !this._queryOperation.indexQuery.waitForNonStaleResults;
        request.url = "/queries";
        request.method = "POST";
        request.query = "?queryHash=" + this._queryOperation.indexQuery.getQueryHash(this._session.conventions.objectMapper);
        request.body = (0, IndexQuery_1.writeIndexQuery)(this._session.conventions, this._queryOperation.indexQuery);
        return request;
    }
    get result() {
        return this._result;
    }
    set result(result) {
        this._result = result;
    }
    get queryResult() {
        return this._queryResult;
    }
    set queryResult(queryResult) {
        this._queryResult = queryResult;
    }
    get requiresRetry() {
        return this._requiresRetry;
    }
    set requiresRetry(result) {
        this._requiresRetry = result;
    }
    async handleResponseAsync(response) {
        if (response.forceRetry) {
            this._result = null;
            this._requiresRetry = true;
            return;
        }
        let queryResult;
        if (response.result) {
            queryResult = await QueryCommand_1.QueryCommand.parseQueryResultResponseAsync((0, StreamUtil_1.stringToReadable)(response.result), this._session.conventions, false);
        }
        this._handleResponse(queryResult, response.elapsed);
    }
    _handleResponse(queryResult, duration) {
        this._queryOperation.ensureIsAcceptableAndSaveResult(queryResult, duration);
        this._parent.emit("afterQueryExecuted", queryResult);
        this.result = this._queryOperation.complete(this._clazz);
        this.queryResult = queryResult;
    }
}
exports.LazyQueryOperation = LazyQueryOperation;
//# sourceMappingURL=LazyQueryOperation.js.map