"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ReplaceClusterCertificateOperation = void 0;
const Exceptions_1 = require("../../../Exceptions");
const RavenCommand_1 = require("../../../Http/RavenCommand");
const RaftIdGenerator_1 = require("../../../Utility/RaftIdGenerator");
class ReplaceClusterCertificateOperation {
    constructor(certBytes, replaceImmediately) {
        if (!certBytes) {
            (0, Exceptions_1.throwError)("InvalidArgumentException", "CertBytes cannot be null");
        }
        this._certBytes = certBytes;
        this._replaceImmediately = replaceImmediately;
    }
    get resultType() {
        return "CommandResult";
    }
    getCommand(conventions) {
        return new ReplaceClusterCertificateCommand(this._certBytes, this._replaceImmediately);
    }
}
exports.ReplaceClusterCertificateOperation = ReplaceClusterCertificateOperation;
class ReplaceClusterCertificateCommand extends RavenCommand_1.RavenCommand {
    constructor(certBytes, replaceImmediately) {
        super();
        if (!certBytes) {
            (0, Exceptions_1.throwError)("InvalidArgumentException", "CertBytes cannot be null");
        }
        this._certBytes = certBytes;
        this._replaceImmediately = replaceImmediately;
    }
    get isReadRequest() {
        return false;
    }
    createRequest(node) {
        const uri = node.url + "/admin/certificates/replace-cluster-cert?replaceImmediately=" + (this._replaceImmediately ? "true" : "false");
        const body = this._serializer.serialize({
            Certificate: this._certBytes.toString("base64")
        });
        return {
            uri,
            method: "POST",
            headers: this._headers().typeAppJson().build(),
            body
        };
    }
    getRaftUniqueRequestId() {
        return RaftIdGenerator_1.RaftIdGenerator.newId();
    }
}
//# sourceMappingURL=ReplaceClusterCertificateOperation.js.map