"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DeleteServerWideTaskOperation = void 0;
const Exceptions_1 = require("../../../Exceptions");
const RavenCommand_1 = require("../../../Http/RavenCommand");
const RaftIdGenerator_1 = require("../../../Utility/RaftIdGenerator");
class DeleteServerWideTaskOperation {
    constructor(name, type) {
        if (!name) {
            (0, Exceptions_1.throwError)("InvalidArgumentException", "Name cannot be null");
        }
        this._name = name;
        this._type = type;
    }
    get resultType() {
        return "CommandResult";
    }
    getCommand(conventions) {
        return new DeleteServerWideTaskCommand(this._name, this._type);
    }
}
exports.DeleteServerWideTaskOperation = DeleteServerWideTaskOperation;
class DeleteServerWideTaskCommand extends RavenCommand_1.RavenCommand {
    constructor(name, type) {
        super();
        if (!name) {
            (0, Exceptions_1.throwError)("InvalidArgumentException", "Name cannot be null");
        }
        this._name = name;
        this._type = type;
        this._responseType = "Empty";
    }
    get isReadRequest() {
        return false;
    }
    getRaftUniqueRequestId() {
        return RaftIdGenerator_1.RaftIdGenerator.newId();
    }
    createRequest(node) {
        const uri = node.url + "/admin/configuration/server-wide/task?type=" + this._type + "&name=" + this._urlEncode(this._name);
        return {
            uri,
            method: "DELETE"
        };
    }
}
//# sourceMappingURL=DeleteServerWideTaskOperation.js.map