"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PutServerWideExternalReplicationOperation = void 0;
const Exceptions_1 = require("../../../Exceptions");
const RavenCommand_1 = require("../../../Http/RavenCommand");
const RaftIdGenerator_1 = require("../../../Utility/RaftIdGenerator");
class PutServerWideExternalReplicationOperation {
    constructor(configuration) {
        if (!configuration) {
            (0, Exceptions_1.throwError)("InvalidArgumentException", "Configuration cannot be null");
        }
        this._configuration = configuration;
    }
    get resultType() {
        return "CommandResult";
    }
    getCommand(conventions) {
        return new PutServerWideExternalReplicationCommand(this._configuration, conventions);
    }
}
exports.PutServerWideExternalReplicationOperation = PutServerWideExternalReplicationOperation;
class PutServerWideExternalReplicationCommand extends RavenCommand_1.RavenCommand {
    constructor(configuration, conventions) {
        super();
        if (!configuration) {
            (0, Exceptions_1.throwError)("InvalidArgumentException", "Configuration cannot be null");
        }
        this._configuration = conventions.objectMapper.toObjectLiteral(configuration);
    }
    get isReadRequest() {
        return false;
    }
    getRaftUniqueRequestId() {
        return RaftIdGenerator_1.RaftIdGenerator.newId();
    }
    createRequest(node) {
        const uri = node.url + "/admin/configuration/server-wide/external-replication";
        const body = this._serializer.serialize(this._configuration);
        return {
            uri,
            method: "PUT",
            headers: this._headers().typeAppJson().build(),
            body
        };
    }
    async setResponseAsync(bodyStream, fromCache) {
        return this._parseResponseDefaultAsync(bodyStream);
    }
}
//# sourceMappingURL=PutServerWideExternalReplicationOperation.js.map