"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LazyGetCompareExchangeValuesOperation = void 0;
const Exceptions_1 = require("../../../../Exceptions");
const TypeUtil_1 = require("../../../../Utility/TypeUtil");
const GetRequest_1 = require("../../../Commands/MultiGet/GetRequest");
const StringUtil_1 = require("../../../../Utility/StringUtil");
const CompareExchangeValueResultParser_1 = require("../../../Operations/CompareExchange/CompareExchangeValueResultParser");
const StringBuilder_1 = require("../../../../Utility/StringBuilder");
const GetCompareExchangeValuesOperation_1 = require("../../../Operations/CompareExchange/GetCompareExchangeValuesOperation");
class LazyGetCompareExchangeValuesOperation {
    constructor(clusterSession, clazz, conventions, keysOrStartsWith, start, pageSize) {
        if (!clusterSession) {
            (0, Exceptions_1.throwError)("InvalidArgumentException", "ClusterSession cannot be null");
        }
        if (!conventions) {
            (0, Exceptions_1.throwError)("InvalidArgumentException", "Conventions cannot be null");
        }
        this._clusterSession = clusterSession;
        this._clazz = clazz;
        this._conventions = conventions;
        if (TypeUtil_1.TypeUtil.isArray(keysOrStartsWith)) {
            this._keys = keysOrStartsWith;
            this._start = 0;
            this._pageSize = 0;
            this._startsWith = null;
        }
        else {
            this._startsWith = keysOrStartsWith;
            this._start = start;
            this._pageSize = pageSize;
            this._keys = null;
        }
    }
    get result() {
        return this._result;
    }
    get queryResult() {
        (0, Exceptions_1.throwError)("NotImplementedException");
        return null;
    }
    get requiresRetry() {
        return this._requiresRetry;
    }
    createRequest() {
        let pathBuilder;
        if (this._keys) {
            for (const key of this._keys) {
                if (this._clusterSession.isTracked(key)) {
                    continue;
                }
                if (!pathBuilder) {
                    pathBuilder = new StringBuilder_1.StringBuilder("?");
                }
                pathBuilder.append("&key=").append(encodeURIComponent(key));
            }
        }
        else {
            pathBuilder = new StringBuilder_1.StringBuilder("?");
            if (StringUtil_1.StringUtil.isNullOrEmpty(this._startsWith)) {
                pathBuilder.append("&startsWith=").append(encodeURIComponent(this._startsWith));
            }
            pathBuilder.append("&start=").append((this._start || 0).toString());
            pathBuilder.append("&pageSize=").append((this._pageSize || 0).toString());
        }
        if (!pathBuilder) {
            this._result = this._clusterSession.getCompareExchangeValuesFromSessionInternal(this._keys, TypeUtil_1.TypeUtil.NOOP, this._clazz);
            return null;
        }
        const request = new GetRequest_1.GetRequest();
        request.url = "/cmpxchg";
        request.method = "GET";
        request.query = pathBuilder.toString();
        return request;
    }
    async handleResponseAsync(response) {
        if (response.forceRetry) {
            this._result = null;
            this._requiresRetry = true;
            return;
        }
        if (response.result) {
            const results = JSON.parse(response.result);
            const localObject = GetCompareExchangeValuesOperation_1.GetCompareExchangeValuesCommand.mapToLocalObject(results);
            if (this._clusterSession.session.noTracking) {
                const result = {};
                for (const kvp of Object.entries(CompareExchangeValueResultParser_1.CompareExchangeValueResultParser.getValues(localObject, false, this._conventions))) {
                    if (!kvp[1].value) {
                        result[kvp[0]] = this._clusterSession.registerMissingCompareExchangeValue(kvp[0]).getValue(this._clazz, this._conventions);
                        continue;
                    }
                    result[kvp[0]] = this._clusterSession.registerCompareExchangeValue(kvp[1]).getValue(this._clazz, this._conventions);
                }
                this._result = result;
                return;
            }
            for (const kvp of Object.entries(CompareExchangeValueResultParser_1.CompareExchangeValueResultParser.getValues(localObject, false, this._conventions))) {
                if (!kvp[1]) {
                    continue;
                }
                this._clusterSession.registerCompareExchangeValue(kvp[1]);
            }
        }
        if (this._keys) {
            for (const key of this._keys) {
                if (this._clusterSession.isTracked(key)) {
                    continue;
                }
                this._clusterSession.registerMissingCompareExchangeValue(key);
            }
        }
        this._result = this._clusterSession.getCompareExchangeValuesFromSessionInternal(this._keys, TypeUtil_1.TypeUtil.NOOP, this._clazz);
    }
}
exports.LazyGetCompareExchangeValuesOperation = LazyGetCompareExchangeValuesOperation;
//# sourceMappingURL=LazyGetCompareExchangeValuesOperation.js.map